@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2016 - David Mohammed
+# Copyright (C) 2015 - 2017 - David Mohammed
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,11 @@
 # define plugin
 
 import rb
+import gi
 from gi.repository import GObject
 from gi.repository import Gio
 from gi.repository import Gtk
+gi.require_version('Peas', '1.0')
 from gi.repository import Peas
 from gi.repository import RB
 
@@ -144,7 +146,8 @@ class AltToolbarPlugin(GObject.Object, Peas.Activatable):
             self.gs.PluginKey.HORIZ_CATEGORIES]
         self.app_menu = self.plugin_settings[
             self.gs.PluginKey.APP_MENU]
-        self.prefer_dark_theme = self.plugin_settings[self.gs.PluginKey.DARK_THEME]
+        self.prefer_dark_theme = \
+            self.plugin_settings[self.gs.PluginKey.DARK_THEME]
 
         # Add the various application view menus
         self.appshell = ApplicationShell(self.shell)
@@ -326,8 +329,9 @@ class AltToolbarPlugin(GObject.Object, Peas.Activatable):
             self.toolbar_type.enable_slider(True)
         else:
             self.toolbar_type.enable_slider(False)
-            label = ""
-            self.toolbar_type.total_time_label.set_markup(label)
+            if (hasattr(self.toolbar_type, "total_time_label")):
+                label = ""
+                self.toolbar_type.total_time_label.set_markup(label)
 
     def _sh_on_song_change(self, player, entry):
         """
