@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2016 David Mohammed
+# Copyright (C) 2015 - 2017 David Mohammed
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,6 +53,14 @@ class AltControllerBase(GObject.Object):
 
         return AltControllerCategory.OTHER
 
+    def toolbar_visibility(self):
+        """
+            return the toolbar visibility
+              by default None which means user controlled
+        """
+
+        return None
+
     def get_gicon(self, source):
         """
           return the source icon
@@ -96,7 +104,7 @@ class AltControllerBase(GObject.Object):
     def get_search_entry(self, toolbar_container):
         """
           find the GtkEntry field corresponding to the search entry
-          returns 1. the GtkWidget containing the GtkEntry 
+          returns 1. the GtkWidget containing the GtkEntry
                   2. the GtkEntry
           returns None if nothing found
         """
@@ -248,6 +256,8 @@ class AltGenericController(AltControllerBase):
                                                new_parent=box)
 
             self.moveto_searchbar(toolbar, search, self.header.searchbar)
+            entry.set_size_request(300, -1)
+
             self.header.searchbar.connect_entry(entry)
             # self.header.searchbar.show_all()
             self.header.searchbar.set_visible(False)
@@ -532,6 +542,9 @@ class AltRadioController(AltGenericController):
     def set_library_labels(self):
         self.header.set_library_labels(song_label=_('Stations'))
 
+    def toolbar_visibility(self):
+        return True # radio source the source toolbar is always shown
+
 
 class AltLastFMController(AltGenericController):
     """
@@ -642,6 +655,9 @@ class AltPodcastController(AltGenericController):
 
         self.header.set_library_labels(song_label=_('Podcasts'))
 
+    def toolbar_visibility(self):
+        return True # podcast source the source toolbar is always shown
+
 
 class AltStandardOnlineController(AltGenericController):
     """
