@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2016 David Mohammed
+# Copyright (C) 2015 - 2017 David Mohammed
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,9 +25,11 @@ import shutil
 import sys
 
 import rb
+import gi
 from gi.repository import GObject
 from gi.repository import Gio
 from gi.repository import Gtk
+gi.require_version('PeasGtk', '1.0')
 from gi.repository import PeasGtk
 from gi.repository import RB
 
