@@ -1,6 +1,6 @@
 # -*- Mode: python; coding: utf-8; tab-width: 4; indent-tabs-mode: nil; -*-
 #
-# Copyright (C) 2015 - 2016 David Mohammed
+# Copyright (C) 2015 - 2017 David Mohammed
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -307,10 +307,14 @@ class AltToolbarBase(GObject.Object):
             print("no page")
             return
 
-        entryview = page.get_entry_view()
+        try:
+            entryview = page.get_entry_view()
 
-        if not entryview:
-            print("no entry view")
+            if not entryview:
+                print("no entry view")
+                return
+        except:
+            # some pages dont have the method to call!
             return
 
         treeview = entryview.get_child()
@@ -318,7 +322,7 @@ class AltToolbarBase(GObject.Object):
         def move_col(*args):
             cols = treeview.get_columns()
 
-            treeview.set_reorderable(True)
+            # treeview.set_reorderable(True)
 
             current_cols = []
             base_col = None
@@ -348,13 +352,13 @@ class AltToolbarBase(GObject.Object):
 
             if element is not None:
                 # we've got something remembered to lets move cols around
-                remembered_col_titles = eval(element.text)
-
+                remembered_col_titles = element.text.split(',')
                 remembered_cols = []
 
                 for title in remembered_col_titles:
+                    compare = title[1:-1]
                     for col in current_cols:
-                        if col.props.title == title:
+                        if col.props.title == compare:
                             remembered_cols.append(col)
                             break
 
@@ -1443,7 +1447,8 @@ class AltToolbarHeaderBar(AltToolbarShared):
         if not self.setup_completed:
             return
 
-        self.set_library_labels()
+        controlled, current_controller = self.is_controlled(self.shell.props.selected_page)
+        current_controller.set_library_labels()
 
         if toggle_button:
             self.emit('song-category-clicked',
@@ -1537,35 +1542,41 @@ class AltToolbarHeaderBar(AltToolbarShared):
         # any source defined controls
         self._end_box_controls.add(self.end_box)
 
-        if (not default.props.gtk_shell_shows_app_menu or
-                default.props.gtk_shell_shows_menubar or
-                self.plugin.app_menu) and \
-                        os.environ["XDG_CURRENT_DESKTOP"].find("GNOME") == -1:
-            # for environments that dont support app-menus
-            menu_button = Gtk.MenuButton.new()
-            # menu_button.set_relief(Gtk.ReliefStyle.NONE)
-            if gtk_version() >= 3.14:
-                symbol = "open-menu-symbolic"
-                menu_button.set_margin_start(3)
-            else:
-                symbol = "emblem-system-symbolic"
-                menu_button.set_margin_left(3)
+        # GNOME design upstream is that main appmenu options should be
+        # within reach of the headerbar with the traditional
+        # appmenu reduced to the occasionally used options
+        # We will reduce the appmenu to just Help, About and Quit option
 
-            image = Gtk.Image.new_from_icon_name(symbol,
-                                                 Gtk.IconSize.SMALL_TOOLBAR)
-            menu_button.add(image)
-            menu = self.shell.props.application.get_shared_menu('app-menu')
-            menu_button.set_menu_model(menu)
-            self._end_box_controls.add(menu_button)
+        menu_button = Gtk.MenuButton.new()
+        if gtk_version() >= 3.14:
+            symbol = "open-menu-symbolic"
+            menu_button.set_margin_start(3)
         else:
-            menu = self.shell.props.application.get_shared_menu('app-menu')
-            app = self.shell.props.application
-            app.set_app_menu(menu)
+            symbol = "emblem-system-symbolic"
+            menu_button.set_margin_left(3)
+
+        image = Gtk.Image.new_from_icon_name(symbol,
+                                             Gtk.IconSize.SMALL_TOOLBAR)
+        menu_button.add(image)
+        menu = self.shell.props.application.get_shared_menu('app-menu')
+        menu_button.set_menu_model(menu)
+        self._end_box_controls.add(menu_button)
+        menu.remove(3) # help about quit
+
+        cl.switch_locale(cl.Locale.RB)
+        appmenu = Gio.Menu.new()
+        appmenu.append(_("_Help"), "app.help")
+        appmenu.append(_("_About"), "app.about")
+        appmenu.append(_("_Quit"), "app.quit")
+        app = self.shell.props.application
+        app.set_app_menu(appmenu)
 
         self.headerbar.pack_end(self._end_box_controls)
         self.headerbar.show_all()
 
-        self.set_library_labels()
+        controlled, current_controller = \
+            self.is_controlled(self.shell.props.selected_page)
+        current_controller.set_library_labels()
 
         action = self.plugin.toggle_action_group.get_action('ToggleToolbar')
         if not self.plugin.start_hidden:
@@ -1593,6 +1604,9 @@ class AltToolbarHeaderBar(AltToolbarShared):
 
         ret, controller = self.is_controlled(page)
         controller.set_library_labels()
+        if controller.toolbar_visibility() is not None:
+            toolbar = controller.get_toolbar(page)
+            toolbar.set_visible(controller.toolbar_visibility())
 
     def _set_toolbar_controller(self):
 
